Documentation
¶
Overview ¶
Package manualclock provides a clock that only advances when explicitly told to.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Ticker ¶
type Ticker event
Ticker represents a "ticker" similar to time.Ticker, except it is controlled by a manual clock.
Source Files
¶
- events.go
- manualclock.go
- wait.go
Click to show internal directories.
Click to hide internal directories.